wagtail_reading_time
================

...

Quick start
-----------

1. Add 'wagtail_reading_time' to your INSTALLED_APPS setting like this:

   ```
   INSTALLED_APPS = [
   ...,
   'wagtail_reading_time',
   ]
   ```

2. ...